aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/project/platform.py
diff options
context:
space:
mode:
Diffstat (limited to 'project/platform.py')
-rw-r--r--project/platform.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/project/platform.py b/project/platform.py
index 92890d0..44118b3 100644
--- a/project/platform.py
+++ b/project/platform.py
@@ -104,8 +104,8 @@ class Platform(Enum):
args += self.b2_stagedir(configuration)
return args
- def makefile_toolchain_file(self):
- # For Makefile generators, we make a special toolchain file that
+ def makefile_toolset_file(self):
+ # For Makefile generators, we make a special toolset file that
# specifies the -m32/-m64 flags, etc.
if self is Platform.AUTO:
# Let the compiler decide.